/*---------------------------------------------------------------------------
 *	fgrab_struct.h
 *
 *	Copyright (c) 2002-2005 Silicon Software GmbH, All Rights Reserved.
 *
 *  Contents:	Definition for Structures Fg_Struct_s , LookupTable_s
 *				DialogInterface_s 
 *
 *----------------------------------------------------------------------------
 */

#ifndef FGRAB_STRUCT_H
#define FGRAB_STRUCT_H

#include "menable.h"

#ifdef MEUNIX 
#else
	#include "windows.h"
#endif


// +------------------------------------------------------------
// Definition of the Lookuptable Parameter structure

typedef struct LookupTable_s {
	unsigned int	*lut;			// pointer to field data, maximum 32 Bit
	unsigned int	id;				// ID (LUT_RED,LUT_GREEN,LUT_BLUE,LUT_GRAY, etc.
	unsigned int	nrOfElements;	// Number of field elements in the lut field	
	unsigned int	format;			// reserved for future use
	unsigned char	number;			// the log number of LUT, if more than one LUT of the same id is used
} LookupTable;

typedef struct KneeLookupTable_s {
	double			*value;			// pointer to field data
	double			*reserved;		// reserved for future use
	unsigned int	id;				// ID (LUT_RED,LUT_GREEN,LUT_BLUE,LUT_GRAY, etc.
	unsigned int	nrOfElements;	// Number of field elements in the lut field	
	unsigned int	format;			// reserved for future use
	unsigned char	number;			// the log number of LUT, if more than one LUT of the same id is used
} KneeLookupTable;


typedef struct ShadingParameter_s {
	unsigned char	*offset;			// pointer to field data, maximum 8 Bit
	unsigned char	*cmult;				// pointer to field mult, range 0.0-<2.0
	float	*mult;						// pointer to field mult, range 0.0-<2.0
	unsigned int	nrOfElements;		// Number of field elements in the offset,mult fields			
	int		width;						// width
	int		height;						// height
	int		set;						// nr of set
} ShadingParameter;

typedef struct LineShadingParameter_s {
	unsigned long mShadingData[4096]; // pointer to field data, maximum 24 Bit
	int		mNoOfPixelsInit;
} LineShadingParameter;

// Fast Config
typedef struct FastConfigSequence_s {
	int		mLengthOfSequence;
	int		*mRoiPagePointer; 
} FastConfigSequence;

typedef struct FastConfigPageCmd_s {
	int		mNoOfCmds;
	int		mPageNr;
	int		mInit;
	int		*mRoiPageCmdPointer; 
} FastConfigPageCmd;

#ifdef __cplusplus
extern "C" {
#endif


typedef struct DialogInterface_s {
	int top,left;
	int width,height;
	int xoffset,yoffset;
	unsigned long exposure;
	double fremepersec;
} DialogInterface;



typedef int		(*FGINTFUNC)(void *fg,...);
typedef void*	(*FGVOIDFUNCINT)(int,...);
typedef void*	(*FGVOIDFUNCPVOID)(void*,...);
typedef char	*(*FGSTRFUNC)(void *fg,...);
typedef int		(*INITFUNC)(int,int,int*);
typedef void	(*CHARFUNC)(char*,...);

typedef int		(*FGINTFUNCSH)(void *fg,void* sh,int x,int channel,float mult);

typedef int (*Fg_AcquireHandler)(int imgNr,void *data);

///////////////////////////////////////////////////////////////////////////////////////////////////
//
//	Name			:	Fg_Struct_s
//	Typ				:	Fg_Struct
//	Contenst		:	This structure defines all the function that are exported to outside
//						, this structure forms the main entry point to all global functions.
//						Any new function exported must be added to the structure.
//	Dependent Comp	:	dll_export.h - This file must be edited to any new fucntions exported,
//						All the fucntion signatures must one the type declared above.
//						grabber_basis.cpp - This file must be edited to implement the new function
//						exported.
//
///////////////////////////////////////////////////////////////////////////////////////////////////
#ifdef INTERNAL
	class Fg_Master;
#endif

typedef struct Fg_Struct_s{
 
#ifdef INTERNAL
	Fg_Master* Master;
#else
	void		*Master;
#endif

	INITFUNC		DLL_Fg_Init;
	FGVOIDFUNCINT	DLL_Fg_InitialiseCamera;
	FGINTFUNC		DLL_Fg_AllocMem;
	FGINTFUNC		DLL_Fg_configure;
	FGVOIDFUNCPVOID DLL_Fg_addApplet;
	FGSTRFUNC  DLL_Fg_getAppletname;
	FGINTFUNC  DLL_Fg_getAppletId;
	FGINTFUNC  DLL_Fg_getLoadAppletId;
	FGINTFUNC  DLL_Fg_getAppletListCount;
	FGINTFUNC  DLL_Fg_setClks;
	FGINTFUNC  DLL_Fg_setParameter;
	FGINTFUNC  DLL_Fg_getParameter;
	FGINTFUNC  DLL_Fg_getParameterEx;
	FGINTFUNC  DLL_Fg_saveConfig;
	FGINTFUNC  DLL_Fg_loadConfig;
	FGINTFUNC  DLL_Fg_Acquire;	
	FGINTFUNC  DLL_Fg_sendSoftwareTrigger;
	FGINTFUNC  DLL_Fg_stopAcquire;
	FGINTFUNC  DLL_Fg_getLastPicNumber;
	FGINTFUNC  DLL_Fg_getLastPicNumberEx;
	FGINTFUNC  DLL_Fg_getLastPicNumberBlocking;
	FGINTFUNC  DLL_Fg_getLastPicNumberBlockingEx;
	FGINTFUNC  DLL_Fg_getLastPicNumberEventEx;
    FGINTFUNC  DLL_Fg_setActBuffer;
    FGINTFUNC  DLL_Fg_getActBuffer;
	FGINTFUNC  DLL_Fg_swapBuffer;
	FGINTFUNC  DLL_Fg_FreeMemEx;
	FGINTFUNC  DLL_Fg_FreeMem;
	FGINTFUNC  DLL_Fg_FreeGrabber;	
	FGINTFUNC  DLL_Fg_getLastErrorNumber;
	FGSTRFUNC  DLL_Fg_getLastErrorDescription;
	FGSTRFUNC  DLL_Fg_getErrorDescription;
	FGINTFUNC  DLL_Fg_getSerialNumber;
	FGINTFUNC  DLL_Fg_getImagePtr;
	FGINTFUNC  DLL_Fg_getImagePtrEx;
	FGINTFUNC  DLL_Fg_doDialog;
    FGINTFUNC  DLL_Fg_closeDialog;
	FGINTFUNC  DLL_Fg_isOpenDialog;
	FGINTFUNC  DLL_Fg_SerialSend;
	FGINTFUNC  DLL_Fg_SerialReceive;
	FGINTFUNC  DLL_INFO;

	FGINTFUNC  DLL_Fg_AllocMemEx;
	FGINTFUNC  DLL_Fg_AllocMemHead;
	FGINTFUNC  DLL_Fg_AddMem;
	FGINTFUNC  DLL_Fg_DelMem;
	FGINTFUNC  DLL_Fg_AddDummyBuffer;
	FGINTFUNC  DLL_Fg_FreeMemHead;
	FGINTFUNC  DLL_Fg_getStatus;
	FGINTFUNC  DLL_Fg_getStatusEx;
	FGINTFUNC  DLL_Fg_setStatus;
	FGINTFUNC  DLL_Fg_setStatusEx;
	FGINTFUNC  DLL_Fg_AcquireEx;
	FGINTFUNC  DLL_Fg_stopAcquireEx;
	FGINTFUNC  DLL_Fg_setExsync;
	FGINTFUNC  DLL_Fg_setFlash;
	FGINTFUNC  DLL_Fg_getImage; 
	FGINTFUNC  DLL_Fg_getImageEx;
	FGINTFUNC  DLL_Fg_getParameterInfo;

	FGVOIDFUNCPVOID DLL_Fg_AllocShading;
	FGINTFUNC DLL_Fg_FreeShading;
	FGINTFUNC DLL_Shad_GetMaxLine;
	FGINTFUNCSH DLL_Shad_SetSubValueLine;
	FGINTFUNCSH DLL_Shad_SetMultValueLine	;
	FGINTFUNC DLL_Shad_SetFixedPatternNoiseLine;
	FGINTFUNC DLL_Shad_GetAccess;
	FGINTFUNC DLL_Shad_FreeAccess;
	FGINTFUNC DLL_Shad_WriteActLine;


	// Function poiner to get Board Pointer
	FGINTFUNC  DLL_Fg_getBoardPointer;
	FGINTFUNC  DLL_Fg_AcquireApcEx;

	#ifdef MEUNIX
		void *dll;
	#else
		HINSTANCE dll;
	#endif

	void *pMem0;
	void *pMem1;

} Fg_Struct;


#ifdef __cplusplus
}
#endif

#endif


