//+-------------------------------------------------------------------
//
//  
//  Copyright (C) Silicon Software GmbH, 1997.
//
//  File:       hap.h
//
//  Contents:   
//              
//
// Revision: 1997 erzeugt
// Okt. 99: Erweiterung um Registerinformationen
// Nov. 99: Erweiterung um Multihap-Funktionalitt und Versionskontrolle
//--------------------------------------------------------------------

#ifndef __HAP1H
#define __HAP1H

#include "os_type_1.h"

#define DIR_READ 0
#define DIR_WRITE 1

#define REGISTER 0x1
#define PULSE    0x2

typedef struct rbt_info 
{
		char designname[256];
		unsigned long family;	// xc4000ex
		char partname[256];
		unsigned long fpga_type;		// 4028exhq240
		char datestring[256];
		int datalen;

		// Clk Data
		unsigned long clk[16];

		unsigned char *data;
} rbt_info;

// Zur Datenbertragung zwischen externene Hap-Zugriffsfunktioenn und der siso.dll

typedef struct HapData {
	union {
		// Add Konfiguration
		rbt_info	*pRbtInfo;

		struct interrupt {
			// AddInterruptRegister
			unsigned long ulBasisAddress;
			unsigned long ulAckRegister;
			unsigned long ulIntStartRegister;
		} interrupt;

		struct dma {
			// AddDmaRegister
			int	nChannel;
			unsigned long ulLenAddr;
			unsigned long ulBaseAddress;
			unsigned long ulFlags;
		} dma;

		struct hregister {
			int				register_type;	// REGISTER, PULSE
			unsigned long	address;		// Absolute Adresse des Registers
			int				cache;			// ein Cache Wert des Registers	
			int				direction;		// Direction Read oder Write
			int				lsb;			// von bit lsb
			int				msb;			// bis bit msb
			char			name[64];		// Namen des Registers
		} hregister;

		struct comment {
			char			str[256];
		} comment;

		struct author {
			char			str[64];
		} author;

		struct version {
			char			str[64];
		} version;

		struct design_name {
			char			str[64];
		} design_name;

		// version 2.0
		struct dma_length {
			int nChannel;
			unsigned long ulAddress;
		} dma_length;

		struct dmatag {
			unsigned long	ulAddress;
			unsigned long	ulMask;
			unsigned long	ulShiftR;
			unsigned long	ulDmaChan;
		} dmatag;

		struct localintreg {
			unsigned long	ulAddress;
		} localintreg;

		struct userintqueue {
			unsigned long	ulAddress;
			unsigned long	ulShiftR;
			unsigned long	ulDmaChan;
			unsigned long	ulQueueDepth;
			unsigned long	ulMaxBurstLength;
		} userintqueue;
		struct license {
			unsigned short user_code;
			unsigned short group_code;
		} license;
	} u;
} HapData;


//
// Tag Header Definitionen
//

#define HAP_HEADER 0x5349534f  // "SISO"

// Multi-Hap-Erweiterung 7.11.99
// Hat einen anderen Header: HAP_MULTI_HEADER
// Dieser ist u.a. um eine Versionkontrolle erweitert

#define HAP_MULTI_HEADER 0x5349534d  // "SISM"


#define HAP_COM			0x08150010
#define HAP_COMMENT		HAP_COM
#define HAP_TAG			0x08150015
#define HAP_FPGA_TYPE	0x08150020

// Version und Revision des Applets ! nicht des Hap-Formats
#define HAP_VERSION		0x08150030
#define HAP_REVISION	0x08150032
#define HAP_RELEASE		0x08150034
#define HAP_DATE		0x08150040
#define HAP_DESCRIP		0x08150050
#define HAP_SPEED		0x08150060
#define HAP_AUTHOR		0x08150070
#define HAP_INTERFACE_INFO 0x08150080
#define HAP_CLOCK		0x08150090
#define HAP_DATA		0x08150110
#define HAP_MULTI_DATA		0x08150120
#define HAP_CONFIG	HAP_MULTI_DATA

#define HAP_REGISTER				0x08151000
#define HAP_DMAMODUL				0x08151010
#define HAP_DMACNTREGISTER			0x08151020
#define HAP_INTERRUPTVECTORREGISTER	0x08151030

#define HAP_DMATAGREGISTER			0x08151040
#define HAP_LOCALINTREGISTER		0x08151050
#define HAP_USERINTQUEUEREAD		0x08151060
#define HAP_USERINTQUEUEWRITE		0x08151070
#define HAP_LICENSECODE				0x08151080

// Erweiterungen fr Multihap

#define HAP_INFO		0x08152000	// Gesamtinfos ber Hap #designs etc.
#define HAP_VERSION_100	0x08153000

// DLL Module ins Hap-Format
#define HAP_DLL			0x08154000

#define HAP_DESIGN_NAME	0x08155000
#define HAP_DESIGN_VERSION 0x08156000

//
// HAP Strukturen 
//

// header 
typedef struct hap_head {
	unsigned long head;	// HAP_HEAD
	unsigned long len;
	unsigned long tag_count;
} hap_head,*phap_head;

// Multi_Header : ab HAP_VERSION_100
typedef struct hap_multi_head {
	unsigned long head;	// HAP_MULTI_HEAD
	unsigned long len;
	unsigned long tag_count;
	unsigned long config_count;	// Die Anzahl der enthaltenen KOnfigurationen
	unsigned long version;	// Erweiterung ab HAP_MULTI_HEAD
	unsigned long destination;	// Zielsystem: microEnable, microEnable-II, etc.
	// PN_MICROENABLE, etc.
} hap_multi_head,*phap_multi_head;


// Hap-Info Struktur mit Informationen ber Teildesigns des Hap-Files
typedef struct hap_info {
	unsigned long tag;
	unsigned long len;
	unsigned long number_of_configurations;
	unsigned long number_of_types;
	unsigned long absolute_config_offsets[64];	// Mindestens 64, bei mehr als 64 conf
												// ist diese Struktur zu erweitern
												// HAP_VERSION_100
} hap_info, *phap_info;

// Comment

typedef struct hap_com_s {
	unsigned long tag;
	unsigned long len;
	char str[256];
	struct hap_com_s *next;
} hap_com_t,*phap_com;

// FPGA type

typedef struct hap_fpga_type {
	unsigned long tag;
	unsigned long len;
	unsigned long type;
	unsigned long speedgrade;
	unsigned long package;
} hap_fpga_type,*phap_fpga_type;

// Author

typedef struct hap_author {
	unsigned long tag;
	unsigned long len;
	char str[64];
} hap_author,*phap_author;

// Design_Name

typedef struct hap_design_name {
	unsigned long tag;
	unsigned long len;
	char str[64];
} hap_design_name,*phap_design_name;

// Design_Name

typedef struct hap_design_version {
	unsigned long tag;
	unsigned long len;
	char str[64];
} hap_design_version,*phap_design_version;


// clocks

// hap data 
typedef struct hap_data {
	unsigned long tag;
	unsigned long len;
	unsigned char *data;
} hap_data,*phap_data;

// NEW: Multidaten, der Typ ist in den Daten integriert !!!

typedef struct hap_multi_data {
	unsigned long tag;
	unsigned long len;

	// FPGA-Type
	unsigned long type;
	unsigned long speedgrade;
	unsigned long package;
	
	// Clock-Einstellungen
	unsigned long clk[16]; //plx_clk, fpga_clk,fpga_div, not used

	// Konfigurationsdaten
	unsigned char *data;
} hap_multi_data,*phap_multi_data;

// hap tag struktur
typedef struct hap_tag {
	unsigned long tag;
	unsigned long len;
} hap_tag,*phap_tag;


// hap register struktur


typedef struct hap_register {
	unsigned long		tag;
	unsigned long		len;
	// 
	int					register_type;	// REGISTER, PULSE
	unsigned long		address;		// Absolute Adresse des Registers
	int					cache;			// ein Cache Wert des Registers	// Pageselect bei Read Registern
	int					direction;		// Direction Read oder Write
	int					lsb;			// von bit lsb
	int					msb;			// bis bit msb
	char				name[64];		// Namen des Registers
	unsigned long*      CachePtr;		// Cache Ptr
	struct hap_register	*next;
} hap_register,*phap_register;

// hap dmamodul struktur
typedef struct hap_dmamodul {
	unsigned long tag;
	unsigned long len;
	int channel;
	unsigned long address;
	int strategie;
} hap_dmamodul,*phap_dmamodul;

// hap intvector struktur
typedef struct hap_intvector {
	unsigned long tag;
	unsigned long len;
	unsigned long basis_address;
	unsigned long ack_address;
	unsigned long start_address;
} hap_intvector,*phap_intvector;

// hap dmacntreg struktur
typedef struct hap_dmacntreg {
	unsigned long tag;
	unsigned long len;
	unsigned long dma_nr;
	unsigned long basis_addr_length_reg;
	unsigned long flags;
} hap_dmacntreg,*phap_dmacntreg;

// hap DLL Struktur, zur Verwaltung der DLL
typedef struct hap_dll {
	unsigned long tag;
	unsigned long len;
	unsigned long version;	// Falls das Datenfeld umgebaut wird !!
	unsigned long prozessor_type;	// i386
	unsigned long operating_system;	// NT4, Linux
	unsigned long ops_version;		// Versionsnummer, gerade bei Linux wichtig
	unsigned long name[64];	// DLL-NAME
	unsigned long *data;
} hap_dll,*phap_dll;

#define HAP_DMATAGREGISTER			0x08151040
#define HAP_LOCALINTREGISTER		0x08151050
#define HAP_USERINTQUEUEREAD		0x08151060

// hap hap_dmatagreg struktur
typedef struct hap_dmatagreg {
	unsigned long tag;
	unsigned long len;
	unsigned long address;
	unsigned long mask;
	unsigned long shiftr;
	unsigned long dma_chan;
} hap_dmatagreg,*phap_dmatagreg;

// hap hap_dmatagreg struktur
typedef struct hap_localintreg {
	unsigned long tag;
	unsigned long len;
	unsigned long address;
} hap_localintreg,*phap_localintreg;

// hap hap_dmatagreg struktur
typedef struct hap_userintqueue {
	unsigned long tag;
	unsigned long len;
	unsigned long address;
	unsigned long shiftr;
	unsigned long dma_chan;
	unsigned long queue_depth;
	unsigned long max_burst_length;
} hap_userintqueue,*phap_hap_userintqueue;

typedef struct hap_license {
	unsigned long tag;
	unsigned long len;
	unsigned short user_code;
	unsigned short group_code;
} hap_license,*phap_license;

//////////////////////////////////////////////
//
// HAP Struktur
//
// Diese Datenstruktur wird zur Konfiguration 
// zurckgegeben
//

typedef struct HAP {
	unsigned long tag_count;
	
	// KOnfigurationsinformationen
	unsigned long data_len; 
	unsigned long type;
	char *data;

	// Design Informationen (for future expansions)
	unsigned long	readback;
	unsigned long   partial_reconfig;

	// Clock Informationen
	unsigned long clk[16]; //plx_clk, fpga_clk,fpga_div, not used

	// Treiber und Bilbliotheksservice-Funktionen
	unsigned long interrupt_vector;	// Addresse des Interrupt Vector, 0 = NOTIMPLEMENTED
	unsigned long interrupt_ack;	// Addresse des Interrupt Acknowledge, 0 = NOTIMPLEMENTED
	unsigned long interrupt_start;	// Addresse des Registers, das die DMA-bertrgaung pro Kanal aktiviert,
									// Spter werden hiermit auch die USER-Interrupts gesteuert
	unsigned long dma_len_register[4];	// Adresse der DMA-Lngenregister, 0 = NOTI
	unsigned long interrupt_vector_funcs[16]; // TODO, Funktions-Zeiger !!!!
	unsigned long dma_flags;

	// DLL Informationen
	int	nr_of_funcs;
	char **func_name;
	char *dll_name;

	// Register Information
	int nrOfRegisters;
	//hap_register	**hapregisterptr;
	int 			*hapregisterptr;
	hap_register	*pregister;
	unsigned long	*Cache;	
	int				PageSelectNr;

	// Comment Information
	int NrOfCom;
	hap_com_t		*coms;

	hap_author		*author;			// Author
	hap_design_name *design_name;		// Design Name
	hap_design_version	*design_version;// Design Version

} HAP,*PHAP;

typedef struct HapTagMaster {
	union {
		hap_head		head;
		hap_multi_head	multi_head;
		hap_info		info;
		hap_tag			tag;
		hap_data		data;
		hap_multi_data	multi_data;
		hap_author		author;
		hap_fpga_type	fpga_typ;
		hap_com_t		hap_com;
		hap_register	reg;
		hap_dmamodul	dmamodul;
		hap_intvector	intvector;
		hap_dmacntreg	dmacntreg;
		hap_dll			dll;
		hap_design_version version;
		hap_design_name design_name;
		hap_dmatagreg	dmatagreg;
		hap_localintreg	localintreg;
		hap_userintqueue	userintqueue;
		hap_license		licensecode;
	} u;
	struct HapTagMaster *next;
} HapTagMaster;

// -------- NEU 10.7.98 ----------

#define MAX_HASH_VAL 4096

typedef struct hash_ele {
	char *name;
	int nr;
	struct hash_ele *next;
} hash_ele_t;


// Neu 18.11.99

// Diese Struktur gibt ein Abbild des Hapfiles
typedef struct hapfile_index {
	int hap_version;
	int nr_of_tags;
	unsigned long *tag;
	unsigned long *absolute_tag_offset;
	int nr_of_configs;
	unsigned long *types;
	unsigned long *absolute_file_offset;
	int NrOfRegister;
	hap_register  *regs;
	int NrOfCom;
	hap_com_t		*coms;
	hap_author		*author;
	hap_design_name *design_name;
	hap_design_version	*design_version;
} hapfile_index,*phapfile_index;

#endif