//+-------------------------------------------------------------------
//
//  
//  Copyright (C) Silicon Software GmbH, 1998.
//
//  File:       me_error.h
//
//  Contents:   
//              
//
//
//--------------------------------------------------------------------

#ifndef __MEERROR1H
#define __MEERROR1H

#include <stdio.h>
#include "os_type_1.h"

#ifdef _WINNT
#include <windows.h>
#endif

/* error codes von init_lib.c */
#define IXR_ROM_BASE_FAILURE          -600 /* unable to write exp rom base register */
#define IXR_ROM_RANGE_FAILURE         -601 /* unable to write exp rom range register */
#define IXR_DESCRIPTOR_FAILURE        -602 /* unable to write exp rom decriptor register */

#define IXS_SLAVE_0_BASE_FAILURE      -610 /* unable to write slave_0 base register */
#define IXS_SLAVE_0_RANGE_FAILURE     -611 /* unable to write slave_0 range register */
#define IXS_DESCRIPTOR_FAILURE        -612 /* unable to write slave_0 decriptor register */

#define INA_DESCRIPTOR_FAILURE        -620 /* unable to write decriptor register */

#define ODD_OPEN_ERROR                -700 /* failed to open device driver */

#define SPD_PCI_DEVICE_NOT_FOUND      -710 /* device with VENDOR_DEVICE_NUMBER not found on PCI bus */

#define SFD_READ_PCI_CONFIG_ERROR     -720 /* unable to read the PCI configuration registers */
#define SFD_WRITE_PCI_CONFIG_ERROR    -725 /* unable to read the PCI configuration registers */

#define IPI_INIT_INTERRUPT_FAILED     -730 /* unable to initialize interrupt handler */


#define RPM_TOO_SMALL_ADDRESS_RANGE   -770 /* too small address range on slave space for 
					      remap expansion rom workaround */
#define RPM_SET_PCI_ROMBASE_ERROR     -771 /* unable to set expansion rom base address in PCI reg */
#define RPM_SET_PCI_SLAVEBASE_ERROR   -772 /* unable to set expansion slv base address in PCI reg */
#define RPM_SLAVE_0_RANGE_FAILURE     -773 /* unable to write slave_0 range register */
#define RPM_READ_PCI_CONFIG_ERROR     -774 /* unable to read the PCI configuration registers */ 

#define ICS_PLX_FREQ_NOT_SET          -780 /* unable to switch plx clock from ref clock to prog. freq. */
#define ICS_DIV_2_FREQ_NOT_SETTABLE   -781 /* unable to set the slow clock to half the speed of the fast */
#define ICS_SLINK_CLK_SOURCE_NOT_SETTABLE -782 /* unable to program s-link as clock source */
#define ICS_SLOW_RAM_CLK_NOT_SETTABLE -783 /* unable to switch cmc conncetor clk to slow clock freq. */

// ---------------------------------------------------------------
/* error codes defines jtag_lib */
/* configure_fpga */

// load design
#define LDS_FILE_NOT_FOUND       -370
#define LDS_NO_FILE_LENGTH       -371
#define LDS_WRONG_NO_CONFIG_BITS -372
#define LDS_FREAD_FAILED         -373


/* prepare_design */
#define   PRC_WRONG_FAMILY_ID              -20
#define   PRC_NO_BITSTREAM_BUFFER          -21
#define   PRC_NO_PREAMBLE_FOUND            -22
#define   PRC_WRONG_LENTH_COUNT            -23

/* buf_expand */
#define   BXP_ZERO_POINTER                 -30

/* */
#define   RDB_ZERO_POINTER                 -40 


#define SFC_FREQ_NOT_SUPPORTED   -110
#define BURST_WRONG_PARAMETER    -120
#define BURST_TIMEOUT            -121
#define SPC_FREQ_NOT_SUPPORTED   -130

// -----

#define CFG_ERROR_UNABLE_SETTING_PROG      -10
#define CFG_ERROR_UNABLE_SETTING_INIT      -11
#define CFG_ERROR_NO_CONFIG_CLEARING       -12     /* init remains high */
#define CFG_ERROR_NO_RESPONSE_ON_DONE      -13
#define CFG_ERROR_CONFIG_MEMORY_NOT_CLEAR  -14     /* init remains low */
#define CFG_ERROR_DOWNLOAD_FAILED          -15     /* done remains low */

// load design
#define LDS_FILE_NOT_FOUND       -370
#define LDS_NO_FILE_LENGTH       -371
#define LDS_WRONG_NO_CONFIG_BITS -372
#define LDS_FREAD_FAILED         -373


/* prepare_design */
#define   PRC_WRONG_FAMILY_ID              -20
#define   PRC_NO_BITSTREAM_BUFFER          -21
#define   PRC_NO_PREAMBLE_FOUND            -22
#define   PRC_WRONG_LENTH_COUNT            -23

/* buf_expand */
#define   BXP_ZERO_POINTER                 -30

/* */
#define   RDB_ZERO_POINTER                 -40 

// ------------------

// load design
#define LDS_FILE_NOT_FOUND       -370
#define LDS_NO_FILE_LENGTH       -371
#define LDS_WRONG_NO_CONFIG_BITS -372
#define LDS_FREAD_FAILED         -373


/* prepare_design */
#define   PRC_WRONG_FAMILY_ID              -20
#define   PRC_NO_BITSTREAM_BUFFER          -21
#define   PRC_NO_PREAMBLE_FOUND            -22
#define   PRC_WRONG_LENTH_COUNT            -23

/* buf_expand */
#define   BXP_ZERO_POINTER                 -30

/* */
#define   RDB_ZERO_POINTER                 -40

// --- old xact_lib

#define CRA_WRONG_DEVICE         -310
#define CRA_ALREADY_INITIALIZED  -311
#define CRA_NO_MEMORY_AVAILABLE  -312
#define CRA_NO_FPGA_SPECIFIED    -313

#define IRA_DEVICE_NOT_SUPPORTED -320


#define URA_ZERO_POINTERS        -330 


#define FRA_MEM_ALREADY_FREED    -340


#define FIB_DEVICE_NOT_SUPPORTED -350
#define FIB_NO_MEMORY_AVAILABLE  -351

#define GLL_FILE_NOT_FOUND       -360

#define LDS_FILE_NOT_FOUND       -370
#define LDS_NO_FILE_LENGTH       -371
#define LDS_WRONG_NO_CONFIG_BITS -372
#define LDS_FREAD_FAILED         -373

///////////////////////////////////////////////////////////////////////////////
// ============================================================================

enum {
	ME_INT_UNDEFINED	= -1, 

	ME_INT_CFG_ERROR_UNABLE_SETTING_PROG_HIGH	= -10, 
	ME_INT_CFG_ERROR_UNABLE_SETTING_PROG_HIGH2= -12, 
	ME_INT_CFG_ERROR_UNABLE_SETTING_PROG_LOW  = -14, 
	ME_INT_CFG_ERROR_UNABLE_SETTING_INIT_HIGH = -16,
	ME_INT_CFG_ERROR_UNABLE_SETTING_INIT_LOW  = -18,
	ME_INT_CFG_ERROR_WAITING_FOR_INIT_LOW			= -20,     /* init remains high */
	ME_INT_CFG_ERROR_WAITING_FOR_INIT_LOW2		= -22,     /* init remains high */
	ME_INT_CFG_ERROR_WAITING_FOR_INIT_HIGH		= -24,
	ME_INT_CFG_ERROR_WAITING_FOR_INIT_HIGH2		= -26,
	ME_INT_CFG_ERROR_WAITING_FOR_DONE_LOW			= -28,
	ME_INT_CFG_ERROR_WAITING_FOR_DONE_HIGH		= -30,
	ME_INT_CFG_ERROR_CONFIG_MEMORY_NOT_CLEAR	= -32,     /* init remains low */
	ME_INT_CFG_ERROR_DOWNLOAD_FAILED					= -34,     /* done remains low */
	ME_INT_CFG_ERROR_MODEPIN_FAILED						= -36,     /* mode pins cannot be set */

	ME_INT_TAL_INTERNAL									 = -100,	// Test and Lock Error
	ME_INT_TAL_INTERNAL2								 = -102,

	ME_INT_LICENSE_NOT_VALID						 = -200,

	ME_INT_GET_DESIGN_NAME							 = -300,
	ME_INT_SET_DESIGN_NAME							 = -310,

	ME_INT_IS_CONFIGURED								 = -400,

	ME_INT_READ_PCI_CONFIG_REGISTER			 = -500,

	ME_INT_LOAD_RBT											 = -600,

	ME_INT_MRB_MAP_RUNTIME_FAILED        = -740, 
	ME_INT_MRB_OPEN_KMEM_FAILED          = -741, 
	ME_INT_MRM_MAP_ROM_FAILED            = -750, 
	ME_INT_MRM_OPEN_KMEM_FAILED          = -751, 
	ME_INT_MPS_MAP_SLAVE_FAILED          = -760, 
	ME_INT_MPS_OPEN_KMEM_FAILED          = -761 
};


enum {
	ME_OK						= 0,

	// BOARD ERRORS
	ME_INVALID_BOARD_POINTER	= -1,
	ME_NOT_INIT								= -2,
	ME_WRONG_DRIVER_VERSION		= -3,
	ME_DEVICE_NOT_FOUND				= -4,
	ME_BOARD_NOT_CONFIGURED		= -5,
	ME_CANNOT_MAP_SPACE				= -6,
	ME_INVALID_PCI_REGISTER		= -7,
	ME_UNSUPPORTED_BOARD_TYPE = -8,
	ME_EEPROM_WRITE_ERROR = -9,

	//LOAD ERRORS
	ME_WRONG_FPGA_TYPE			= -20,
	ME_WRONG_CONFIG_SIZE		= -21,

	//CONFIGURE ERRORS
	ME_CANNOT_CONFIGURE		= -26,
	ME_NOT_CONFIGURED			= -27,

	// DMA ERRORS
	ME_TIMEOUT					= -30,
	ME_INVALID_DMA_LEN	= -31,
	ME_INVALID_DMA_BUF	= -32,
	ME_INVALID_DMA_CHAN	= -34,
	ME_INVALID_PARAMETER= -35,
	ME_DMA_STILL_IN_PROGRESS	= -36,
	ME_OUTOFRANGE= -37,

	// GENERAL ERRORS
	ME_NOT_ENOUGH_MEM			= -50,
	ME_FILE_NOT_FOUND			= -51,
	ME_INTERNAL_ERROR			= -52,			
	ME_CANNOT_GET_STATUS	= -53,
	ME_NOT_IMPLEMENTED    = -54,
	ME_DLL_NOT_FOUND			= -55,

	// MEMORY LOCKING ERRORS
	ME_BUFFER_TOO_LARGE			= -80,
	ME_CANNOT_LOCK_BUFFER		= -81,
	ME_BUFFER_ALREADY_LOCKED	= -82,
	ME_INVALID_BUFFER			= -83,
	ME_BUFFER_IN_USE			= -84,

	// SYSTEM LOCKING
	ME_SYSTEM_LOCKED			= -100,
	ME_RESSOURCES_STILL_IN_USE  = -101,
	ME_CLOCK_NOT_LOCKED			= -102,
	ME_SYSTEM_LOCKED_BY_ANOTHER_PROCESS	= -103,

	// LICENSE
	ME_INVALID_LICENSEKEY		= -110,
	ME_NO_VALID_LICENSE			= -111,
	ME_LAST_ERROR				= -112	
};


#endif


